Crate reflow_actor

Crate reflow_actor 

Modules

frame_pool
Shared frame pool — zero-copy ring buffer for passing large frames between actors without channel congestion.
history
journal
message
process
stream
types

Structs

ActorConfig
Enhanced configuration for actors containing metadata, environment variables, and resolved config
ActorContext
ActorLoad
Graph
This class represents an abstract FBP graph containing nodes connected to each other with edges. These graphs can be used for visualization and sketching, but also are the way to start an FBP network.
MemoryState

Enums

ConfigError

Traits

Actor
ActorState
MaybeSend
Cross-target Send/Sync markers.
MaybeSync

Type Aliases

ActorBehavior
Type-erased actor body. The closure produces a future that resolves to the actor’s port outputs.
ActorChannel
ActorPayload
Port