Modules
- frame_
pool - Shared frame pool — zero-copy ring buffer for passing large frames between actors without channel congestion.
- history
- journal
- message
- process
- stream
- types
Structs
- Actor
Config - Enhanced configuration for actors containing metadata, environment variables, and resolved config
- Actor
Context - Actor
Load - Graph
- This class represents an abstract FBP graph containing nodes connected to each other with edges. These graphs can be used for visualization and sketching, but also are the way to start an FBP network.
- Memory
State
Enums
Traits
- Actor
- Actor
State - Maybe
Send - Cross-target
Send/Syncmarkers. - Maybe
Sync
Type Aliases
- Actor
Behavior - Type-erased actor body. The closure produces a future that resolves to the actor’s port outputs.
- Actor
Channel - Actor
Payload - Port